<?php
namespace Bushelpowered\Api\Platform\Tenant\V1;

use \Bushelpowered\Api\Common\Request\UUIDRequest;
use \Bushelpowered\Api\Platform\Tenant\V1\Response\DatasourceGetResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\ConstraintViolation;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bushelpowered\Api\Common\NotFound;
use \Bidl\Php\Core\Builtins\UnknownError;

class GetDatasourceById 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    public function call(UUIDRequest $request, $headers): DatasourceGetResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | NotFound | UnknownError
    {
         return $this->client->call('api/platform/tenant/v1/GetDatasourceById', $request, new GetDatasourceByIdResponseWrapper(), $headers)->response;
    }
}

class GetDatasourceByIdResponseWrapper implements \Bidl\Php\Core\BIDlResponse {

    /** @var DatasourceGetResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | NotFound | UnknownError */
    public $response;

    public function __construct()
    {
        $this->mapper = new \JsonMapper();
    }
    
    public function fromJson($data) 
    {
        switch($data->type) {
          case 'api.platform.tenant.v1#GetDatasourceByIdSuccess':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Platform\Tenant\V1\Response\DatasourceGetResponse::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#BadRequest':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#ConstraintViolation':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\ConstraintViolation::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#NotAuthenticated':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#NotAuthorized':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#NotFound':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotFound::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
           default: 
             $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
        }
    }
}